ChangeCase extension

Extensions getters on String to preform common, identifier-related conversions.

on

Methods

isLowerCase() → bool

Available on String, provided by the ChangeCase extension

Checkes if whole string is lowercase.
isUpperCase() → bool

Available on String, provided by the ChangeCase extension

Checkes if whole string is uppercase.
toCamelCase() → String

Available on String, provided by the ChangeCase extension

Converts to a string with the separators denoted by having the next letter capitalized
toCapitalCase() → String

Available on String, provided by the ChangeCase extension

Converts to a lowercased, first letter captialized word, space separated string of every word
toConstantCase() → String

Available on String, provided by the ChangeCase extension

Converts to an upper case, underscore separated string
toDotCase() → String

Available on String, provided by the ChangeCase extension

Converts to a lower case period separated string
toHeaderCase() → String

Available on String, provided by the ChangeCase extension

Converts to a captialized word, dash separated string
toKebabCase() → String

Available on String, provided by the ChangeCase extension

Converts to a lower case, dash separated string
toLowerFirstCase() → String

Available on String, provided by the ChangeCase extension

Converts to a string with the first character lower cased
toNoCase() → String

Available on String, provided by the ChangeCase extension

Converts the string without any casing (lower case, space separated)
toParamCase() → String

Available on String, provided by the ChangeCase extension

Same as toKebabCase
toPascalCase() → String

Available on String, provided by the ChangeCase extension

Converts to a string denoted in the same fashion as camel but with the first letter capitalized
toPathCase([String? separator]) → String

Available on String, provided by the ChangeCase extension

Converts to a lower case, slash separated string
toSentenceCase() → String

Available on String, provided by the ChangeCase extension

Converts to a lower case, space separated string with the first letter capitalized
toSnakeCase() → String

Available on String, provided by the ChangeCase extension

Converts to a lower case, underscore separated string
toSpongeCase() → String

Available on String, provided by the ChangeCase extension

Converts to a string with every character randomly lowercased/capitalized
toSwapCase() → String

Available on String, provided by the ChangeCase extension

Converts to a string with every character case reversed
toTitleCase() → String

Available on String, provided by the ChangeCase extension

Converts to a space separated string with the
toUpperFirstCase() → String

Available on String, provided by the ChangeCase extension