LastMoveGetter extension

on

Properties

lastMoveFrom → Position?

Available on ChessBoardInterface, provided by the LastMoveGetter extension

Returns the Position from which a ChessPiece was moved, deduced by comparing the second last and last FEN strings.
no setter
lastMoveTo → Position?

Available on ChessBoardInterface, provided by the LastMoveGetter extension

Returns the "to Position square" where a ChessPiece was moved, deduced by comparing the second last and last FEN strings.
no setter